import path from 'path'
import express from 'express'
import cors from 'cors'
import coreStart from './core.js'
import { handleRequest } from './src/Requests/RequestHandler.js'
import { log } from './src/Controllers/LogController.js'
import scheduler from './src/Libs/Scheduler.js'
import AutoRechargeController from './src/Controllers/AutoRechargeController.js'

// const RedisStore = connectRedis(session)
// const client = new Redis()
const app = express()
const frontendFiles = path.join(path.dirname(process.argv[1]), '..', 'mobile', 'static');

app.use(cors({
    origin: '*',
    methods: ['GET', 'POST', 'PUT', 'PATCH', 'DELETE'],
    allowedHeaders: ['Content-Type', 'Authorization'],
    credentials: true,
    origin: true
}))
app.use(express.static(frontendFiles))

app.options('*', (req, res) => {
    res.header('Access-Control-Allow-Methods', 'PUT, POST, PATCH, DELETE, GET')
    res.header('Access-Control-Allow-Headers', 'Content-Type, Authorization')
    res.status(200).send()
})

// app.use(
//     session({
//         // store,
//         // store: new RedisStore({ client: client }),
//         store: new session.MemoryStore(),
//         secret: crypto.randomBytes(32).toString('hex'),
//         resave: false,
//         saveUninitialized: false,
//         cookie: {
//             maxAge: 60 * 60 * 1000, // Session expiration time (in milliseconds)
//             secure: process.env.secure, // Set to true if using HTTPS
//             sameSite: process.env.sameSite, // Set to 'none' if using cross-origin requests (CORS)
//         },
//     })
// )

app.post('/API/gracefulShutdown', () => {
    log({ type: 'info', message: `Restarting backend Graceful Shutdown` })
    process.exit(0)
})

app.post('*', handleRequest)
// app.get('*', handleRequest)

coreStart().then(() => {
    const PORT = 5000
    app.listen(PORT, () => {
        log({ type: 'info', message: `Server running on port ${PORT}` })

        AutoRechargeController.checkAutoRecharges(true)
        scheduler.startSchedule(AutoRechargeController.checkAutoRecharges)
    })
})
