import LoginRepository from '../Repositories/LoginRepository.js'
import ConsumerRepository from '../Repositories/ConsumerRepository.js'
import EmailController from './EmailController.js'
import FoodRestrictionController from './FoodRestrictionController.js'
import { getRetailGeneralParamsBackend } from './RetailParamsController.js'
import md5 from 'md5'
import moment from 'moment'
import jwt from 'jsonwebtoken'

const login = async function (req, body, consDetails) {
    let dbResult = []
    let response = {}

    if (consDetails) {
        body = {...consDetails, ...body}
        body.client = body.CDCLIENTE
        body.filial = body.CDFILIAL
    }

    if (hasAllParameters(body) && process.env.usa_instituicao_cliente_filial === 'N') {
        dbResult = await LoginRepository.login(body)
    } else if (process.env.usa_instituicao_cliente_filial === 'S') {
        if (hasAllParameters(body)) {
            dbResult = await LoginRepository.loginSaporeWithClient(body)
        } else {
            dbResult = await LoginRepository.loginClientless(body)
        }
    }

    if (dbResult?.length > 1) dbResult = removeDuplicated(dbResult)

    if (dbResult?.length === 1) {
        response.token = md5(`teknisa ${moment().format('DDMMYYYY')}`)
        consDetails = await ConsumerRepository.getConsumerDetails(dbResult[0])
        const CDFILIAL = process.env.usa_instituicao_cliente_filial === 'S' ? dbResult[0].CDFILIAL : body.filial 
        response[process.env.TOKEN_HEADER_KEY] = jwt.sign({ CDFILIAL, ...consDetails }, process.env.JWT_SECRET_KEY)
        
        if (process.env.usa_instituicao_cliente_filial === 'S') {
            response.baseInfo = {
                CDCLIENTE: dbResult[0].CDCLIENTE,
                CDFILIAL: dbResult[0].CDFILIAL,
                NMFANTCLIE: dbResult[0].NMFANTCLIE,
            }
        }

        // Verifica e replica as restrições alimentares dos consumidores da conta se necessário, de maneira assíncrona
        // para não atrasar o login
        FoodRestrictionController.replicateProductRestrictions(CDFILIAL, consDetails)
    } else if (dbResult?.length > 1) {
        return {
            showSelectPopup: true,
            options: dbResult
        }
    } else {
        const password = await ConsumerRepository.getPassword({
            CDCLIENTE: body.client,
            NMLOGINCONS: body.username
        })

        const today = moment().format('YYYYMMDD')
        const checkingCode = (md5(body.username + today)).substring(0, 5)
        const tempPassword = `passRecover${checkingCode}`
        const recProcess = password?.CDSENHACONSMD5 === tempPassword

        if (recProcess) {
            response.token = ''
            response.message = 'Conta em processo de recuperação. Siga as instruções descritas no email enviado.'
        } else {
            response.token = ''
            response.message = 'Não foi possível encontrar o login do usuário'
        }

    }
    response.NMRESPCONS = consDetails?.NMRESPCONS || null
    response.ACCTERMOSUSOAPP = consDetails?.ACCTERMOSUSOAPP || 'N'
    console.log(consDetails)
    return response
}

const hasAllParameters = (body) => {
    return body && body.username != null && body.username != ''
        && ((body.password != null && body.password != '') || (body.refreshToken != null && body.refreshToken != ''))
        && body.client != null && body.client != ''
        && body.filial != null && body.filial != ''
}

const removeDuplicated = (dbResult) => {
    let filteredResult = []
    filteredResult.push(dbResult[0])

    for (let i = 1; i < dbResult.length; i++) {
        const current = dbResult[i]
        let alreadyExists = filteredResult.find(element => element.NRCPFRESPCON === current.NRCPFRESPCON && element.CDCLIENTE === current.CDCLIENTE)
        if (!alreadyExists) filteredResult.push(current)
    }

    return filteredResult
}

const getClients = async function () {
    return LoginRepository.getClients()
}

const forgotPassword = async function (body) {
    // verificar se o usuário existe
    let { CDCLIENTE, NMLOGINCONS } = body
    if (CDCLIENTE === '') CDCLIENTE = null
    let dbResult = []

    if (CDCLIENTE) {
        dbResult = await LoginRepository.getConsumerByLoginRecover(CDCLIENTE, NMLOGINCONS)
    } else {
        dbResult = await LoginRepository.getConsumerClientlessRecover(NMLOGINCONS)
    }

    if (dbResult?.length === 0) {
        return {
            error: true,
            message: 'Usuário não encontrado'
        }
    } else if (dbResult?.length === 1 && !dbResult[0].DSEMAILCONS) {
        return {
            error: true,
            message: 'Usuário não possui e-mail cadastrado. Favor entrar em contato com o administrador do sistema.'
        }
    }

    if (dbResult?.length > 1) dbResult = removeDuplicated(dbResult)

    if (dbResult?.length > 1) {
        return {
            showSelectPopup: true,
            options: dbResult
        }
    } else {
        let consumerData = dbResult[0]
    
        // atualizar a senha para uma senha temporária
        const today = moment().format('YYYYMMDD')
        const checkingCode = (md5(NMLOGINCONS + today)).substring(0, 5)
        const tempPassword = `passRecover${checkingCode}`
    
        if (process.env.usa_instituicao_cliente_filial === 'S' && CDCLIENTE == null) {
            body.CDCLIENTE = consumerData.CDCLIENTE
        }

        const result = await ConsumerRepository.changePassword(body, tempPassword)
        result.email = consumerData.DSEMAILCONS
        result.checkingCode = checkingCode
        result.userName = consumerData.NMRESPCONS
    
        // enviar e-mail com a senha temporária
        const emailResult = await EmailController.sendEmail({ DSEMAILCONS: consumerData.DSEMAILCONS, subject: 'Recuperação de senha', consDetails: body , htmlFunction: 'getForgotPasswordEmail', functionParams: { name: consumerData.NMRESPCONS, checkingCode } })
        
        result.emailSent = emailResult.accepted?.length > 0
        const retailParams = await getRetailGeneralParamsBackend()
        result.customMsg = retailParams?.RECSENHAMSG ? retailParams.RECSENHAMSG : 'Foi encaminhado um e-mail com o link para geração de uma nova senha para o endereço cadastrado na conta. Caso não tenha mais acesso a este endereço de e-mail, favor entrar em contato com a supervisão.'
    
        if (process.env.usa_instituicao_cliente_filial === 'S' && CDCLIENTE == null) {
            result.CDCLIENTE = consumerData.CDCLIENTE
        }

        return result
    }
}

const updatePasswordAfterRecover = async function (body) {  
    const { newPassword } = body
    const CDSENHACONSMD5 = md5(`odhen${newPassword}7833`)
    
    const result = await ConsumerRepository.changePassword(body, CDSENHACONSMD5)
    return result 
}

const activateUser = async function (body) {
    return LoginRepository.activateUser(body)
}

const blockUser = async function (body) {
    return LoginRepository.blockUser(body)
}

export default { login, getClients, forgotPassword, updatePasswordAfterRecover, activateUser, blockUser }
