
import { executeQuery } from '../Connection/QueriesExecutor.js'

const getFoodRestriction = async function (consDetails, CDCONSUMIDOR) {
    const { CDFILIAL, CDCLIENTE } = consDetails
    const result = await executeQuery({sql: 'GET_PRODUCT_RESTRICTIONS', 
        binds: { CDFILIAL, CDCLIENTE, CDCONSUMIDOR },
        rawReturn: true
    })
    return result
}

const updateFoodRestriction = async function (consDetails, CDCONSUMIDOR, QTCONSDIARAL, IDPAI, CDPRODUTO, cdWeekDays) {
    const { CDCLIENTE } = consDetails
    const IDBLOQDIARAL = cdWeekDays
    const CDFAMILISALD = IDPAI
    const result = await executeQuery({sql: 'UPDATE_PRODUCT_RESTRICTION',
        binds: { 
            QTCONSDIARAL,
            IDBLOQDIARAL, 
            CDCLIENTE,
            CDCONSUMIDOR,
            CDFAMILISALD,
            CDPRODUTO
        },
        rawReturn: true,
        commit: true
    })

    return result
}

const getConsumerFamilies = async function (consDetails) {
    const { CDFILIAL } = consDetails
    const result = await executeQuery({sql: 'GET_CONSUMER_FAMILIES',
        binds: { CDFILIAL },
        rawReturn: true
    })

    return result
}

const getFamilyProducts = async function (consDetails, CDCONSUMIDOR, CDFAMILISALD) {
    const { CDFILIAL, CDCLIENTE } = consDetails
    const result = await executeQuery({sql: 'GET_FAMILY_PRODUCTS',
        binds: { CDFILIAL, CDFAMILISALD, CDCLIENTE, CDCONSUMIDOR },
        rawReturn: true
    })

    return result
}

const getValueRestriction = async function (consDetails, CDCONSUMIDOR, CDFAMILISALD, CDFILIAL) {
    const { CDCLIENTE } = consDetails
    const result = await executeQuery({sql: 'GET_VALUE_RESTRICTION',
        binds: { CDFILIAL, CDCLIENTE, CDCONSUMIDOR, CDFAMILISALD },
        rawReturn: true
    })

    return result
}

const addValueRestriction = async function (consDetails, CDCONSUMIDOR, CDFAMILISALD, VRCONSDIARAL, CDFILIAL) {
    const { CDCLIENTE } = consDetails
    const result = await executeQuery({sql: 'ADD_VALUE_RESTRICTION',
        binds: {
            CDFILIAL,
            CDCLIENTE,
            CDCONSUMIDOR,
            CDFAMILISALD,
            VRCONSDIARAL
        },
        rawReturn: true,
        commit: true
    })

    return result
}


const addFoodRestriction = async function (consDetails, CDCONSUMIDOR, CDPRODUTO, CDFAMILISALD, QTCONSDIARAL, cdWeekDays, CDFILIAL, CDCLIENTE) {
    const IDBLOQDIARAL = cdWeekDays
    const result = await executeQuery({sql: 'ADD_PRODUCT_RESTRICTION',
        binds: {
            CDFILIAL,
            CDCLIENTE,
            CDCONSUMIDOR,
            CDFAMILISALD,
            CDPRODUTO,
            QTCONSDIARAL,
            IDBLOQDIARAL
        },
        rawReturn: true,
        commit: true
    })

    return result
}

const deleteFoodRestriction = async function (consDetails, CDCONSUMIDOR, CDFAMILISALD, CDPRODUTO ) {
    const { CDCLIENTE } = consDetails
    const result = await executeQuery({sql: 'DELETE_PRODUCT_RESTRICTION',
        binds: {
            CDCLIENTE,
            CDCONSUMIDOR,
            CDFAMILISALD,
            CDPRODUTO
        },
        rawReturn: true,
        commit: true
    })

    return result
}

const getClientBranchList = async function (CDCLIENTE) {
    const result = await executeQuery({sql: 'GET_CLIENT_BRANCH_LIST',
        binds: { CDCLIENTE },
        rawReturn: true
    })

    return result
}

const getConsumerProductRestrictions = async function (CDFILIAL, CDCLIENTE, CDCONSUMIDOR) {
    const result = await executeQuery({sql: 'GET_CONSUMER_PRODUCT_RESTRICTIONS',
        binds: { CDFILIAL, CDCLIENTE, CDCONSUMIDOR },
        rawReturn: true
    })

    return result
}

const checkProductRestriction = async function (CDFILIAL, CDCLIENTE, CDCONSUMIDOR, CDPRODUTO, CDFAMILISALD) {
    const result = await executeQuery({sql: 'CHECK_PRODUCT_RESTRICTION',
        binds: { CDFILIAL, CDCLIENTE, CDCONSUMIDOR, CDPRODUTO, CDFAMILISALD },
        rawReturn: true
    })

    return result
}

export default {
    getFoodRestriction,
    updateFoodRestriction,
    getConsumerFamilies,
    getFamilyProducts,
    getValueRestriction,
    addValueRestriction,
    addFoodRestriction,
    deleteFoodRestriction,
    getClientBranchList,
    getConsumerProductRestrictions,
    checkProductRestriction
}
